==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/DavaMonitor/DavaMonitor.h <==
// public class soot.dava.toolkits.base.DavaMonitor.DavaMonitor

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class dee2bc6f63bc2553 soot_dava_toolkits_base_DavaMonitor_DavaMonitor

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_DavaMonitor_DavaMonitor_H_
#define _JC_soot_dava_toolkits_base_DavaMonitor_DavaMonitor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_LinkedList$object;
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_refs	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_nonrefs	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$refs	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$refs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$nonrefs	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object;

typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$fields_struct	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$fields_struct;
typedef const struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vmethods	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtable	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtable;
typedef const struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtype	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtype;

// Class fields structure
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$fields_struct {
	struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object	*instance;
};
extern _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$fields_struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$class_fields;

// Constructors
extern void _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object *);

// Virtual methods
extern void _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$method$enter$9fe506f0c86348be(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object *, struct _jc_java_lang_Object$object *);
extern void _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$method$exit$4747c1d350dd59eb(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$method_info$enter$9fe506f0c86348be;
extern _jc_method _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$method_info$exit$4747c1d350dd59eb;

// Static methods
extern void _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object *_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$method$v$9084e4f8db2d88b3(_jc_env *);

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vmethods {
	void	(*enter$9fe506f0c86348be)(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object *, struct _jc_java_lang_Object$object *);
	void	(*exit$4747c1d350dd59eb)(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vmethods	soot_dava_toolkits_base_DavaMonitor_DavaMonitor;
};

// Vtype
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_refs {
	struct _jc_java_util_HashMap$object	*ref;
	struct _jc_java_util_HashMap$object	*lockTable;
	struct _jc_java_util_LinkedList$object	*q;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$refs {
    _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_refs	soot_dava_toolkits_base_DavaMonitor_DavaMonitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_nonrefs	soot_dava_toolkits_base_DavaMonitor_DavaMonitor;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object {
	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtype	*vtype;
	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtype _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_DavaMonitor_DavaMonitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$class_object;

#endif	/* _JC_soot_dava_toolkits_base_DavaMonitor_DavaMonitor_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/DavaMonitor/DavaMonitor.h <==
// public class soot.dava.toolkits.base.DavaMonitor.DavaMonitor

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class dee2bc6f63bc2553 soot_dava_toolkits_base_DavaMonitor_DavaMonitor

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_DavaMonitor_DavaMonitor_H_
#define _JC_soot_dava_toolkits_base_DavaMonitor_DavaMonitor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_LinkedList$object;
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_refs	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_nonrefs	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$refs	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$refs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$nonrefs	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object;

typedef struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$fields_struct	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$fields_struct;
typedef const struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vmethods	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtable	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtable;
typedef const struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtype	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtype;

// Class fields structure
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$fields_struct {
	struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object	*instance;
};
extern _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$fields_struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$class_fields;

// Constructors
extern void _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$method$enter$9fe506f0c86348be(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$method$exit$4747c1d350dd59eb(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$method_info$enter$9fe506f0c86348be;
extern _jc_method _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$method_info$exit$4747c1d350dd59eb;

// Static methods
extern void _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object *_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$method$v$9084e4f8db2d88b3(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vmethods {
	void	(*enter$9fe506f0c86348be)(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*exit$4747c1d350dd59eb)(_jc_env *, struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vmethods	soot_dava_toolkits_base_DavaMonitor_DavaMonitor;
};

// Vtype
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_refs {
	struct _jc_java_util_HashMap$object	*ref;
	struct _jc_java_util_HashMap$object	*lockTable;
	struct _jc_java_util_LinkedList$object	*q;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$refs {
    _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_refs	soot_dava_toolkits_base_DavaMonitor_DavaMonitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$sub_nonrefs	soot_dava_toolkits_base_DavaMonitor_DavaMonitor;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$object {
	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtype	*vtype;
	_jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$vtype _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_DavaMonitor_DavaMonitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_DavaMonitor_DavaMonitor$class_object;

#endif	/* _JC_soot_dava_toolkits_base_DavaMonitor_DavaMonitor_H_ */
